<?php

namespace Drupal\files_url_replacer;

use Drupal\Core\File\FileUrlGenerator;
use Drupal\Core\StreamWrapper\StreamWrapperManager;

/**
 * Replace baseurl.
 */
class CustomFileUrlGenerator extends FileUrlGenerator {

  /**
   * {@inheritdoc}
   */
  public function generateString(string $uri) : string {
    $string = parent::generateString($uri);
    $active = \Drupal::config('files_url_replacer.settings')->get('active');
    $ext = pathinfo($uri, PATHINFO_EXTENSION);
    $exclude = ['css', 'js'];

    if ($string && $active && !in_array($ext, $exclude) && StreamWrapperManager::getScheme($uri) == 'public') {
      $url = \Drupal::config('files_url_replacer.settings')->get('url');
      if (!empty($url) && $this->checkIfExists($uri)) {
        $string = rtrim($url, '/') . $string;
      }
    }

    return $string;
  }

  /**
   * {@inheritdoc}
   */
  public function generateAbsoluteString(string $uri) : string {
    $string = parent::generateAbsoluteString($uri);
    $active = \Drupal::config('files_url_replacer.settings')->get('active');
    $ext = pathinfo($uri, PATHINFO_EXTENSION);
    $exclude = ['css', 'js'];

    if ($string && $active && !in_array($ext, $exclude) && StreamWrapperManager::getScheme($uri) == 'public') {
      $url = \Drupal::config('files_url_replacer.settings')->get('url');
      if (!empty($url) && $this->checkIfExists($uri)) {
        $string = str_replace(\Drupal::request()->getSchemeAndHttpHost(), rtrim($url, '/'), $string);
      }
    }

    return $string;
  }

  /**
   * {@inheritdoc}
   */
  private function checkIfExists(string $uri) : bool {
    $check = \Drupal::config('files_url_replacer.settings')->get('check');
    if ($check == TRUE && file_exists($uri)) {
      return FALSE;
    }

    return TRUE;
  }

}
