<?php

namespace Drupal\files_url_replacer\Form;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure files ur replacer integration settings for this site.
 */
class FilesUrlReplacerSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'files_url_replacer_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['files_url_replacer.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('files_url_replacer.settings');

    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Activate Replacer'),
      '#default_value' => $config->get('active'),
      '#description' => $this->t("Check to activate files url replacer."),
    ];

    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('URL'),
      '#default_value' => $config->get('url'),
      '#description' => $this->t("Enter the URL you want to serve your files from."),
      '#states' => [
        'visible' => [
          ':input[name="active"]' => ['checked' => TRUE],
        ],
        'required' => [
          ':input[name="active"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['check'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Check if local file exists'),
      '#default_value' => $config->get('check'),
      '#description' => $this->t("Checks if the file exists localy and only replaces URL if it doesn't."),
      '#states' => [
        'visible' => [
          ':input[name="active"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue('active') && empty($form_state->getValue('url'))) {
      $form_state->setErrorByName('url', $this->t('URL is required'));
    }

    if (!empty($form_state->getValue('url'))) {
      $url = $form_state->getValue('url');
      if (!UrlHelper::isValid($url, TRUE) || !UrlHelper::isExternal($url)) {
        $form_state->setErrorByName('url', $this->t('Invalid URL'));
      }
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('files_url_replacer.settings')
      ->set('active', $form_state->getValue('active'))
      ->set('url', $form_state->getValue('url'))
      ->set('check', $form_state->getValue('check'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
